// 
// Copyright (C) 2006, NinjaTrader LLC <www.ninjatrader.com>.
// NinjaTrader reserves the right to modify or overwrite this NinjaScript component with each release.
//

#region Using declarations
using System;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.ComponentModel;
using System.Xml.Serialization;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
	/// <summary>
	/// The balance of power indicator measures the strength of the bulls vs. bears by assessing the ability of each to push price to an extreme level.
	/// </summary>
	[Description("The balance of power indicator measures the strength of the bulls vs. bears by assessing the ability of each to push price to an extreme level.")]
	public class PRV : Indicator
	{
		#region Variables
		private DataSeries	prv;
		private double prvnum = 0;
		#endregion

		/// <summary>
		/// This method is used to configure the indicator and is called once before any bar data is loaded.
		/// </summary>
		protected override void Initialize()
		{
			Add(new Plot(new Pen(Color.Gold, 2), PlotStyle.Bar, "PRV"));

			prv			= new DataSeries(this);
			
			Overlay		= false;
			PriceTypeSupported	= false;
			CalculateOnBarClose = false;
		}
		
		/// <summary>
		/// Called on each bar update event (incoming tick)
		/// </summary>
		protected override void OnBarUpdate()
		{
			if (Bars.PercentComplete < .02) // prv.Set( Volume[0] ) ;
				prvnum = Volume[0]; 
			else //prv.Set( Volume[0]/Bars.PercentComplete - (Volume[0]/Bars.PercentComplete % 1) );
				prvnum = Volume[0]/Bars.PercentComplete - (Volume[0]/Bars.PercentComplete % 1);
			//  using modulo to truncate into a whole number, another way below? 
			//  prv.Set( Math.Floor(Volume[0]/Bars.PercentComplete) );
			prv.Set(prvnum);
			Value.Set(prvnum);
		}

		#region Properties

		#endregion
	}
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private PRV[] cachePRV = null;

        private static PRV checkPRV = new PRV();

        /// <summary>
        /// The balance of power indicator measures the strength of the bulls vs. bears by assessing the ability of each to push price to an extreme level.
        /// </summary>
        /// <returns></returns>
        public PRV PRV()
        {
            return PRV(Input);
        }

        /// <summary>
        /// The balance of power indicator measures the strength of the bulls vs. bears by assessing the ability of each to push price to an extreme level.
        /// </summary>
        /// <returns></returns>
        public PRV PRV(Data.IDataSeries input)
        {

            if (cachePRV != null)
                for (int idx = 0; idx < cachePRV.Length; idx++)
                    if (cachePRV[idx].EqualsInput(input))
                        return cachePRV[idx];

            PRV indicator = new PRV();
            indicator.SetUp();
            indicator.BarsRequired = BarsRequired;
            indicator.CalculateOnBarClose = CalculateOnBarClose;
            indicator.Input = input;

            PRV[] tmp = new PRV[cachePRV == null ? 1 : cachePRV.Length + 1];
            if (cachePRV != null)
                cachePRV.CopyTo(tmp, 0);
            tmp[tmp.Length - 1] = indicator;
            cachePRV = tmp;
            Indicators.Add(indicator);

            return indicator;
        }

    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// The balance of power indicator measures the strength of the bulls vs. bears by assessing the ability of each to push price to an extreme level.
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.PRV PRV()
        {
            return _indicator.PRV(Input);
        }

        /// <summary>
        /// The balance of power indicator measures the strength of the bulls vs. bears by assessing the ability of each to push price to an extreme level.
        /// </summary>
        /// <returns></returns>
        public Indicator.PRV PRV(Data.IDataSeries input)
        {
            return _indicator.PRV(input);
        }

    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// The balance of power indicator measures the strength of the bulls vs. bears by assessing the ability of each to push price to an extreme level.
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.PRV PRV()
        {
            return _indicator.PRV(Input);
        }

        /// <summary>
        /// The balance of power indicator measures the strength of the bulls vs. bears by assessing the ability of each to push price to an extreme level.
        /// </summary>
        /// <returns></returns>
        public Indicator.PRV PRV(Data.IDataSeries input)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.PRV(input);
        }

    }
}
#endregion
