// 
// Copyright (C) 2006, NinjaTrader LLC <www.ninjatrader.com>.
// NinjaTrader reserves the right to modify or overwrite this NinjaScript component with each release.
//

#region Using declarations
using System;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.ComponentModel;
using System.Xml.Serialization;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
	/// <summary>
	/// Volume is simply the number of shares (or contracts) traded during a specified time frame (e.g. hour, day, week, month, etc).
	/// </summary>
	[Description("Volume is simply the number of shares (or contracts) traded during a specified time frame (e.g. hour, day, week, month, etc).")]
	[Gui.Design.DisplayName("VolumeTriColor")]
	public class VolumeTriColor : Indicator
	{
		/// <summary>
		/// This method is used to configure the indicator and is called once before any bar data is loaded.
		/// </summary>
		protected override void Initialize()
		{
			Add(new Plot(new Pen(Color.Black, 2), PlotStyle.Bar, "VolumeUp"));
			Add(new Plot(new Pen(Color.Red, 2), PlotStyle.Bar, "VolumeDown"));
			Add(new Plot(new Pen(Color.MediumOrchid, 2), PlotStyle.Bar, "VolumeEQ"));
			Add(new Line(Color.DarkGray, 0, "Zero line"));
			
			ChartOnly			= true;
			Overlay				= false;
			CalculateOnBarClose = false;
			DrawOnPricePanel 	= false;
			PaintPriceMarkers 	= true;
			DisplayInDataBox 	= false; 
		}

		/// <summary>
		/// Called on each bar update event (incoming tick)
		/// </summary>
		protected override void OnBarUpdate()
		{
			if (CurrentBar < 1)						// First bar?
			{										// Yes.
				Values[2].Set(Volume[0]);			// Plot it as an "equal" volume.
				return;								// Done.
			}
			if (Close[0] > Close[1])					// Is PRICE up over last bar?
				Values[0].Set(Volume[0]);			// Yes.  Plot it as an "up" volume.

			else if (Close[0] < Close[1])
				Values[1].Set(Volume[0]);			// Yes.  Plot it as an "down" volume.
	
			else 
				Values[2].Set(Volume[0]);			// Yes.  Plot it as an "equal" volume.				
		}
	}
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private VolumeTriColor[] cacheVolumeTriColor = null;

        private static VolumeTriColor checkVolumeTriColor = new VolumeTriColor();

        /// <summary>
        /// Volume is simply the number of shares (or contracts) traded during a specified time frame (e.g. hour, day, week, month, etc).
        /// </summary>
        /// <returns></returns>
        public VolumeTriColor VolumeTriColor()
        {
            return VolumeTriColor(Input);
        }

        /// <summary>
        /// Volume is simply the number of shares (or contracts) traded during a specified time frame (e.g. hour, day, week, month, etc).
        /// </summary>
        /// <returns></returns>
        public VolumeTriColor VolumeTriColor(Data.IDataSeries input)
        {

            if (cacheVolumeTriColor != null)
                for (int idx = 0; idx < cacheVolumeTriColor.Length; idx++)
                    if (cacheVolumeTriColor[idx].EqualsInput(input))
                        return cacheVolumeTriColor[idx];

            VolumeTriColor indicator = new VolumeTriColor();
            indicator.SetUp();
            indicator.BarsRequired = BarsRequired;
            indicator.CalculateOnBarClose = CalculateOnBarClose;
            indicator.Input = input;

            VolumeTriColor[] tmp = new VolumeTriColor[cacheVolumeTriColor == null ? 1 : cacheVolumeTriColor.Length + 1];
            if (cacheVolumeTriColor != null)
                cacheVolumeTriColor.CopyTo(tmp, 0);
            tmp[tmp.Length - 1] = indicator;
            cacheVolumeTriColor = tmp;
            Indicators.Add(indicator);

            return indicator;
        }

    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// Volume is simply the number of shares (or contracts) traded during a specified time frame (e.g. hour, day, week, month, etc).
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.VolumeTriColor VolumeTriColor()
        {
            return _indicator.VolumeTriColor(Input);
        }

        /// <summary>
        /// Volume is simply the number of shares (or contracts) traded during a specified time frame (e.g. hour, day, week, month, etc).
        /// </summary>
        /// <returns></returns>
        public Indicator.VolumeTriColor VolumeTriColor(Data.IDataSeries input)
        {
            return _indicator.VolumeTriColor(input);
        }

    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// Volume is simply the number of shares (or contracts) traded during a specified time frame (e.g. hour, day, week, month, etc).
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.VolumeTriColor VolumeTriColor()
        {
            return _indicator.VolumeTriColor(Input);
        }

        /// <summary>
        /// Volume is simply the number of shares (or contracts) traded during a specified time frame (e.g. hour, day, week, month, etc).
        /// </summary>
        /// <returns></returns>
        public Indicator.VolumeTriColor VolumeTriColor(Data.IDataSeries input)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.VolumeTriColor(input);
        }

    }
}
#endregion
